@@ -6,7 +6,7 @@ use warnings;
 use re '/saa';
 use utf8;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Encode qw/encode/;
 use File::Slurp;
@@ -94,12 +94,12 @@ EOF
 }
 
 sub run {
-	my ($user_or_path) = @_;
+	my ($args, $user_or_path) = @_;
 	my $stats;
 	if ($user_or_path =~ /^\w+$/) { # Looks like a user
-		$stats = naodash_user $user_or_path
+		$stats = naodash_user $args, $user_or_path
 	} else {
-		$stats = naodash_xlog read_file $user_or_path
+		$stats = naodash_xlog $args, read_file $user_or_path
 	}
 	print encode 'UTF-8', naodash_to_ansi $stats ## no critic (RequireCheckedSyscalls)
 }
